# -*- coding: iso-8859-1 -*-

"""
    MoinMoin - MinimalMoin theme
    @copyright: 2009, 2010 Paul Boddie <paul@boddie.org.uk>
    @copyright: (portions) 2003-2008 MoinMoin:ThomasWaldmann, 2003-2005 Nir Soffer
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin.theme import ThemeBase
from MoinMoin import i18n
from MoinMoin import wikiutil
from MoinMoin import version
from MoinMoin.Page import Page
import re

class Theme(ThemeBase):

    name = "minimalmoin"

    # Icon definitions from the modernized theme...

    _ = lambda x: x     # We don't have gettext at this moment, so we fake it
    icons = {
        # key         alt                        icon filename      w   h
        # FileAttach
        'attach':     ("%(attach_count)s",       "moin-attach.png",   16, 16),
        'info':       ("[INFO]",                 "moin-info.png",     16, 16),
        'attachimg':  (_("[ATTACH]"),            "attach.png",        32, 32),
        # RecentChanges
        'rss':        (_("[RSS]"),               "moin-rss.png",      16, 16),
        'deleted':    (_("[DELETED]"),           "moin-deleted.png",  16, 16),
        'updated':    (_("[UPDATED]"),           "moin-updated.png",  16, 16),
        'renamed':    (_("[RENAMED]"),           "moin-renamed.png",  16, 16),
        'conflict':   (_("[CONFLICT]"),          "moin-conflict.png", 16, 16),
        'new':        (_("[NEW]"),               "moin-new.png",      16, 16),
        'diffrc':     (_("[DIFF]"),              "moin-diff.png",     16, 16),
        # General
        'bottom':     (_("[BOTTOM]"),            "moin-bottom.png",   16, 16),
        'top':        (_("[TOP]"),               "moin-top.png",      16, 16),
        'www':        ("[WWW]",                  "moin-www.png",      16, 16),
        'mailto':     ("[MAILTO]",               "moin-email.png",    16, 16),
        'news':       ("[NEWS]",                 "moin-news.png",     16, 16),
        'telnet':     ("[TELNET]",               "moin-telnet.png",   16, 16),
        'ftp':        ("[FTP]",                  "moin-ftp.png",      16, 16),
        'file':       ("[FILE]",                 "moin-ftp.png",      16, 16),
        # search forms
        'searchbutton': ("[?]",                  "moin-search.png",   16, 16),
        'interwiki':  ("[%(wikitag)s]",          "moin-inter.png",    16, 16),

        # smileys (this is CONTENT, but good looking smileys depend on looking
        # adapted to the theme background color and theme style in general)
        #vvv    ==      vvv  this must be the same for GUI editor converter
        'X-(':        ("X-(",                    'angry.png',         16, 16),
        ':D':         (":D",                     'biggrin.png',       16, 16),
        '<:(':        ("<:(",                    'frown.png',         16, 16),
        ':o':         (":o",                     'redface.png',       16, 16),
        ':(':         (":(",                     'sad.png',           16, 16),
        ':)':         (":)",                     'smile.png',         16, 16),
        'B)':         ("B)",                     'smile2.png',        16, 16),
        ':))':        (":))",                    'smile3.png',        16, 16),
        ';)':         (";)",                     'smile4.png',        16, 16),
        '/!\\':       ("/!\\",                   'alert.png',         16, 16),
        '<!>':        ("<!>",                    'attention.png',     16, 16),
        '(!)':        ("(!)",                    'idea.png',          16, 16),
        ':-?':        (":-?",                    'tongue.png',        16, 16),
        ':\\':        (":\\",                    'ohwell.png',        16, 16),
        '>:>':        (">:>",                    'devil.png',         16, 16),
        '|)':         ("|)",                     'tired.png',         16, 16),
        ':-(':        (":-(",                    'sad.png',           16, 16),
        ':-)':        (":-)",                    'smile.png',         16, 16),
        'B-)':        ("B-)",                    'smile2.png',        16, 16),
        ':-))':       (":-))",                   'smile3.png',        16, 16),
        ';-)':        (";-)",                    'smile4.png',        16, 16),
        '|-)':        ("|-)",                    'tired.png',         16, 16),
        '(./)':       ("(./)",                   'checkmark.png',     16, 16),
        '{OK}':       ("{OK}",                   'thumbs-up.png',     16, 16),
        '{X}':        ("{X}",                    'icon-error.png',    16, 16),
        '{i}':        ("{i}",                    'icon-info.png',     16, 16),
        '{1}':        ("{1}",                    'prio1.png',         15, 13),
        '{2}':        ("{2}",                    'prio2.png',         15, 13),
        '{3}':        ("{3}",                    'prio3.png',         15, 13),
        '{*}':        ("{*}",                    'star_on.png',       16, 16),
        '{o}':        ("{o}",                    'star_off.png',      16, 16),
    }
    del _

    stylesheets = (
        # media         basename
        ('all',         'combined'),
        )

    def header(self, d, **kw):
        """ Assemble page header

        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """

        request = self.request
        fmt = request.formatter
        html = []

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        show_section_numbers = fmt._show_section_numbers
        fmt._show_section_numbers = 0

        # The header section.

        html.append(fmt.div(on=1, attr={"id" : "header"}))

        html.append(self.title(d))
        html.append(self.about(d))
        html.append(self.mainpages(d))

        html.append(fmt.div(on=0))

        # Show any pertinent message.

        html.append(self.msg(d))

        # Complete the header.

        html.append(self.startPage())

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        fmt._show_section_numbers = show_section_numbers

        return u''.join(html)

    editorheader = header

    def footer(self, d, **kw):
        """ Assemble page footer

        @param d: parameter dictionary
        @rtype: unicode
        @return: page footer html
        """

        request = self.request
        fmt = request.formatter
        _ = request.getText
        page = d["page"]
        html = []

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        show_section_numbers = fmt._show_section_numbers
        fmt._show_section_numbers = 0

        # End the page.

        html.append(self.endPage())

        # The footer section.

        html.append(fmt.div(on=1, attr={"id" : "footer"}))

        if self.shouldShowEditbar(page):
            html.append(self.menuholder(d, {"class" : "editing"}, _("Editing options"), self.editbar))
        html.append(self.menuholder(d, {"id" : "navigation"}, _("Useful pages"), self.navibar))
        html.append(self.menuholder(d, {"id" : "identity"}, _("User information"), self.username))

        #html.append(self.trail(d))

        html.append(fmt.div(on=0))

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        fmt._show_section_numbers = show_section_numbers

        return u''.join(html)

    def mainpages(self, d, **kw):
        """ Link to the front page and potentially other pages.

        @param d: parameter dictionary
        @rtype: unicode
        @return: front page link html
        """

        request = self.request
        fmt = request.formatter
        _ = request.getText
        html = []

        page = wikiutil.getFrontPage(self.request)

        html.append(fmt.bullet_list(on=1, attr={"id" : "mainpages"}))
        html.append(fmt.listitem(on=1))
        html.append(page.link_to(request, text=_("Front page"), rel='nofollow'))
        html.append(fmt.listitem(on=0))
        html.append(fmt.bullet_list(on=0))

        return u''.join(html)

    def about(self, d, **kw):
        """ Link to the controls in the footer.

        @param d: parameter dictionary
        @rtype: unicode
        @return: about link html
        """

        request = self.request
        fmt = request.formatter
        _ = request.getText
        html = []

        html.append(fmt.bullet_list(on=1, attr={"id" : "pageabout"}))
        html.append(fmt.listitem(on=1))

        html.append(fmt.anchorlink(on=1, name="footer"))
        html.append(fmt.text(_("About this page")))
        html.append(fmt.anchorlink(on=0))

        html.append(fmt.listitem(on=0))
        html.append(fmt.bullet_list(on=0))

        return u''.join(html)

    def menuholder(self, d, menu_attr, menu_title, menu_fn):
        """ Wrap controls in a menu container.

        @param d: parameter dictionary
        @param menu_attr: menu container element attributes
        @param menu_title: the menu label text
        @param menu_fn: the function or method producing the controls
        @rtype: unicode
        @return: menu container html
        """

        request = self.request
        fmt = request.formatter
        html = []

        html.append(fmt.div(on=1, attr=menu_attr))
        html.append(fmt.span(on=1, attr={"class" : "menutitleholder"}))
        html.append(fmt.span(on=1, attr={"class" : "menutitle"}))
        html.append(fmt.text(menu_title))
        html.append(fmt.span(on=0))
        html.append(menu_fn(d))
        html.append(fmt.span(on=0))
        html.append(fmt.div(on=0))

        return u''.join(html)

# Theme instantiation.

def execute(request):
    """
    Generate and return a theme object

    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

# vim: tabstop=4 expandtab shiftwidth=4
